==> OOo_2.2.1_Win32Intel_solver_curvirgo.zip: solver/680/wntmsci10.pro/inc/offuh/com/sun/star/smarttags/XSmartTagAction.hpp <==
#ifndef _COM_SUN_STAR_SMARTTAGS_XSMARTTAGACTION_HPP_
#define _COM_SUN_STAR_SMARTTAGS_XSMARTTAGACTION_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_SMARTTAGS_XSMARTTAGACTION_HDL_
#include "com/sun/star/smarttags/XSmartTagAction.hdl"
#endif

#ifndef _COM_SUN_STAR_UNO_RUNTIMEEXCEPTION_HPP_
#include "com/sun/star/uno/RuntimeException.hpp"
#endif
#ifndef _COM_SUN_STAR_TEXT_XTEXTRANGE_HPP_
#include "com/sun/star/text/XTextRange.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_XINTERFACE_HPP_
#include "com/sun/star/uno/XInterface.hpp"
#endif
#ifndef _COM_SUN_STAR_FRAME_XCONTROLLER_HPP_
#include "com/sun/star/frame/XController.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_ANY_HXX_
#include "com/sun/star/uno/Any.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_SEQUENCE_HXX_
#include "com/sun/star/uno/Sequence.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif

namespace com { namespace sun { namespace star { namespace smarttags {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::smarttags::XSmartTagAction const *) {
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_INTERFACE, "com.sun.star.smarttags.XSmartTagAction" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
}

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::uno::Reference< ::com::sun::star::smarttags::XSmartTagAction > const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::uno::Reference< ::com::sun::star::smarttags::XSmartTagAction > >::get();
}

::com::sun::star::uno::Type const & ::com::sun::star::smarttags::XSmartTagAction::static_type(void *) {
    return ::getCppuType(static_cast< ::com::sun::star::uno::Reference< ::com::sun::star::smarttags::XSmartTagAction > * >(0));
}

#endif // _COM_SUN_STAR_SMARTTAGS_XSMARTTAGACTION_HPP_

==> OOo_2.3.0_Win32Intel_solver_curvirgo.zip: solver/680/wntmsci10.pro/inc/offuh/com/sun/star/smarttags/XSmartTagAction.hpp <==
#ifndef _COM_SUN_STAR_SMARTTAGS_XSMARTTAGACTION_HPP_
#define _COM_SUN_STAR_SMARTTAGS_XSMARTTAGACTION_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_SMARTTAGS_XSMARTTAGACTION_HDL_
#include "com/sun/star/smarttags/XSmartTagAction.hdl"
#endif

#ifndef _COM_SUN_STAR_LANG_ILLEGALARGUMENTEXCEPTION_HPP_
#include "com/sun/star/lang/IllegalArgumentException.hpp"
#endif
#ifndef _COM_SUN_STAR_LANG_XINITIALIZATION_HPP_
#include "com/sun/star/lang/XInitialization.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_RUNTIMEEXCEPTION_HPP_
#include "com/sun/star/uno/RuntimeException.hpp"
#endif
#ifndef _COM_SUN_STAR_LANG_LOCALE_HPP_
#include "com/sun/star/lang/Locale.hpp"
#endif
#ifndef _COM_SUN_STAR_TEXT_XTEXTRANGE_HPP_
#include "com/sun/star/text/XTextRange.hpp"
#endif
#ifndef _COM_SUN_STAR_CONTAINER_XSTRINGKEYMAP_HPP_
#include "com/sun/star/container/XStringKeyMap.hpp"
#endif
#ifndef _COM_SUN_STAR_LANG_INDEXOUTOFBOUNDSEXCEPTION_HPP_
#include "com/sun/star/lang/IndexOutOfBoundsException.hpp"
#endif
#ifndef _COM_SUN_STAR_FRAME_XCONTROLLER_HPP_
#include "com/sun/star/frame/XController.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif

namespace com { namespace sun { namespace star { namespace smarttags {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::smarttags::XSmartTagAction const *) {
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_INTERFACE, "com.sun.star.smarttags.XSmartTagAction" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
}

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::uno::Reference< ::com::sun::star::smarttags::XSmartTagAction > const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::uno::Reference< ::com::sun::star::smarttags::XSmartTagAction > >::get();
}

::com::sun::star::uno::Type const & ::com::sun::star::smarttags::XSmartTagAction::static_type(void *) {
    return ::getCppuType(static_cast< ::com::sun::star::uno::Reference< ::com::sun::star::smarttags::XSmartTagAction > * >(0));
}

#endif // _COM_SUN_STAR_SMARTTAGS_XSMARTTAGACTION_HPP_
